@@ -1,4 +1,4 @@
-from client import Client
+from .client import Client
 
 
 class Post(Client):
