@@ -1,10 +1,11 @@
 import unittest
-from author import Author
-from butter_cms import ButterCMS
-from category import Category
-from content_field import ContentField
-from feed import Feed
-from post import Post
+from .author import Author
+from .butter_cms import ButterCMS
+from .category import Category
+from .tag import Tag
+from .content_field import ContentField
+from .feed import Feed
+from .post import Post
 auth_token = 'f97d131d955f48af0769a4c827bb47728cbd5d05'
 
 
@@ -70,6 +71,32 @@ class TestCategory(TestAPI):
             self.assertIn('recent_posts', post)
 
 
+class TestTag(TestAPI):
+    def test_all(self):
+        tag = Tag(auth_token)
+        response = tag.all()
+        self.is_ok_request(response)
+
+    def test_all_include(self):
+        tag = Tag(auth_token)
+        response = tag.all(params={'include':'recent_posts'})
+        self.is_ok_request(response)
+        for tag_post in response['data']:
+            self.assertIn('recent_posts', tag_post)
+
+    def test_get(self):
+        tag = Tag(auth_token)
+        response = tag.get('beer')
+        self.is_ok_request(response)
+
+    def test_get_include(self):
+        tag = Tag(auth_token)
+        response = tag.get(params={'include':'recent_posts'})
+        self.is_ok_request(response)
+        for post in response['data']:
+            self.assertIn('recent_posts', post)
+
+
 class TestContentField(TestAPI):
     def test_get(self):
         content_field = ContentField(auth_token)
